@@ -10,11 +10,14 @@ fields in each record may be populated. See
 http://dev.maxmind.com/geoip/geoip2/web-services for more details.
 
 """
-# pylint:disable=R0903
+# pylint: disable=too-many-instance-attributes,too-few-public-methods
+from abc import ABCMeta
+
 import geoip2.records
+from geoip2.mixins import SimpleEquality
 
 
-class Country(object):
+class Country(SimpleEquality):
 
     """Model for the GeoIP2 Precision: Country and the GeoIP2 Country database
 
@@ -66,6 +69,7 @@ class Country(object):
     def __init__(self, raw_response, locales=None):
         if locales is None:
             locales = ['en']
+        self._locales = locales
         self.continent = \
             geoip2.records.Continent(locales,
                                      **raw_response.get('continent', {}))
@@ -76,11 +80,10 @@ class Country(object):
             geoip2.records.Country(locales,
                                    **raw_response.get('registered_country',
                                                       {}))
-        # pylint:disable=bad-continuation
         self.represented_country \
             = geoip2.records.RepresentedCountry(locales,
                                                 **raw_response.get(
-                                                'represented_country', {}))
+                                                    'represented_country', {}))
 
         self.maxmind = \
             geoip2.records.MaxMind(**raw_response.get('maxmind', {}))
@@ -88,6 +91,13 @@ class Country(object):
         self.traits = geoip2.records.Traits(**raw_response.get('traits', {}))
         self.raw = raw_response
 
+    def __repr__(self):
+        return '{module}.{class_name}({data}, {locales})'.format(
+            module=self.__module__,
+            class_name=self.__class__.__name__,
+            data=self.raw,
+            locales=self._locales)
+
 
 class City(Country):
 
@@ -230,7 +240,75 @@ class Insights(City):
     """
 
 
-class ConnectionType(object):
+class SimpleModel(SimpleEquality):
+
+    """Provides basic methods for non-location models"""
+
+    __metaclass__ = ABCMeta
+
+    def __repr__(self):
+        # pylint: disable=no-member
+        return '{module}.{class_name}({data})'.format(
+            module=self.__module__,
+            class_name=self.__class__.__name__,
+            data=str(self.raw))
+
+
+class AnonymousIP(SimpleModel):
+
+    """Model class for the GeoIP2 Anonymous IP
+
+    This class provides the following attribute:
+
+    .. attribute:: is_anonymous
+
+      This is true if the IP address belongs to any sort of anonymous network.
+
+      :type: bool
+
+    .. attribute:: is_anonymous_vpn
+
+      This is true if the IP address belongs to an anonymous VPN system.
+
+      :type: bool
+
+    .. attribute:: is_hosting_provider
+
+      This is true if the IP address belongs to a hosting provider.
+
+      :type: bool
+
+    .. attribute:: is_public_proxy
+
+      This is true if the IP address belongs to a public proxy.
+
+      :type: bool
+
+    .. attribute:: is_tor_exit_node
+
+      This is true if the IP address is a Tor exit node.
+
+      :type: bool
+
+    .. attribute:: ip_address
+
+      The IP address used in the lookup.
+
+      :type: unicode
+    """
+
+    def __init__(self, raw):
+        self.is_anonymous = raw.get('is_anonymous', False)
+        self.is_anonymous_vpn = raw.get('is_anonymous_vpn', False)
+        self.is_hosting_provider = raw.get('is_hosting_provider', False)
+        self.is_public_proxy = raw.get('is_public_proxy', False)
+        self.is_tor_exit_node = raw.get('is_tor_exit_node', False)
+
+        self.ip_address = raw.get('ip_address')
+        self.raw = raw
+
+
+class ConnectionType(SimpleModel):
 
     """Model class for the GeoIP2 Connection-Type
 
@@ -262,7 +340,7 @@ class ConnectionType(object):
         self.raw = raw
 
 
-class Domain(object):
+class Domain(SimpleModel):
 
     """Model class for the GeoIP2 Domain
 
@@ -288,7 +366,7 @@ class Domain(object):
         self.raw = raw
 
 
-class ISP(object):
+class ISP(SimpleModel):
 
     """Model class for the GeoIP2 ISP
 
